|Opps|
======
.. |Opps| image:: docs/source/_static/opps.jpg
    :alt: Opps Open Source Content Management Platform

An *Open Source Content Management Platform* for the **magazine** websites and **high-traffic**, using the Django Framework.

.. image:: https://travis-ci.org/opps/opps.png
    :target: https://travis-ci.org/opps/opps


Contacts
========
The place to create issues is `opps's github issues <https://github.com/opps/opps/issues>`_. The more information you send about an issue, the greater the chance it will get fixed fast.

If you are not sure about something, have a doubt or feedback, or just want to ask for a feature, feel free to join `our mailing list <http://groups.google.com/group/opps-developers>`_, or, if you're on FreeNode (IRC), you can join the chat #opps .


Sponsor
=======

* `YACOWS <http://yacows.com.br/>`_


License
=======

Copyright 2013 Opps Project. and other contributors

Licensed under the `MIT License <http://www.oppsproject.org/en/latest/#license>`_
